<?php
$lang['abbr_length'] = 'Д';
$lang['abbr_width'] = 'Ш';
$lang['abbr_height'] = 'В';
$lang['add'] = 'Добавить';
$lang['addcategory'] = 'Добавить категорию';
$lang['addfielddef'] = 'Добавить поле';
$lang['adjustable'] = 'Вручную';
$lang['addproduct'] = 'Добавить продукт';
$lang['add_attrib_set'] = 'Добавить атрибут';
$lang['add_category_field'] = 'Associate Field with Category: "%s"';
$lang['add_hierarchy_item'] = 'Добавить элемент в иерархию';
$lang['add_option'] = 'Добавить вариант атрибута';
$lang['admin_only'] = 'Атрибуты доступны только админу?';
$lang['align_ul'] = 'Вверху слева';
$lang['align_uc'] = 'Вверзу в центре';
$lang['align_ur'] = 'Вверху справа';
$lang['align_ml'] = 'Посередине слева';
$lang['align_mc'] = 'В центре';
$lang['align_mr'] = 'Посередине справа';
$lang['align_ll'] = 'Внизу слева';
$lang['align_lc'] = 'Внизу в центре';
$lang['align_lr'] = 'Внизу справа';
$lang['all'] = 'Все';
$lang['allcategories'] = 'Все категории';
$lang['any'] = 'Любой';
$lang['areyousure'] = 'Вы уверены?';
$lang['areyousure_deleteproduct'] = 'Вы уверены, что хотите удалить этот товар, и всю информацию о нем?';
$lang['ascending'] = 'По возрастанию';
$lang['attribute_name'] = 'Название атрибута';
$lang['automatic'] = 'Автоматически';
$lang['byhierarchytemplates'] = 'Шаблоны иерархии';
$lang['byhierarchytemplate_addedit'] = 'Добавить/Изменить шаблон вывода иерархии';
$lang['cancel'] = 'Отмена';
$lang['categories'] = 'Категории';
$lang['category'] = 'Категория';
$lang['categoryexists'] = 'Категория с таким именем уже существует';
$lang['categorylisttemplates'] = 'Шаблон списка категорий';
$lang['categorylisttemplate_addedit'] = 'Добавить/Редактировать шаблон списка категорий';
$lang['centimeters'] = 'Сантиметры';
$lang['checkbox'] = 'Чекбокс';
$lang['confirm_copyattributes'] = 'Все существующие атрибуты продукты будут удалены. Вы уверены, что хотите продолжить?';
$lang['confirm_delete_hierarchy_node'] = 'Вы уверены, что хотите удалить этот узел? Все продукты, находещиеся в узле будут перемещены в корень';
$lang['confirm_import'] = 'Вы уверены, что хотите удалить?\\n\\nНеверные настройки или конфигурация может полностью нарушить работоспособность Вашего сайта.';
$lang['copy'] = 'Копировать';
$lang['copy_attrib_sets'] = 'Скопировать атрибуты продукта';
$lang['copy_category'] = 'Копировать категорию';
$lang['createddate'] = 'Создан';
$lang['current_value'] = 'Значение';
$lang['data'] = 'Дата';
$lang['default'] = 'По умолчанию';
$lang['defaulttemplates'] = 'Шаблоны по умолчанию';
$lang['default_template_notice'] = '<strong>Note:</strong> The contents of these text areas are used to determine the default content of templates when you click "Add Template" in the appropriate template tab.  Editing one of these text areas will have no immediate effect on your website.';
$lang['delete'] = 'Удалить';
$lang['delete_attribset'] = 'Удалить атрибут';
$lang['delete_hierarchy_item'] = 'Удалить Элемент Иерархии';
$lang['descending'] = 'По убыванию';
$lang['description'] = 'Описание';
$lang['destination'] = 'Назначение';
$lang['details'] = 'Описание';
$lang['detailtemplates'] = 'Шаблон Карточки товара';
$lang['detailtemplate_addedit'] = 'Добавить/Редактировать шаблон карточки товара';
$lang['dimensions'] = 'Размеры';
$lang['disabled'] = 'Отключено';
$lang['down'] = 'Передвинуть вниз';
$lang['draft'] = 'Черновик';
$lang['dropdown'] = 'Выпадающий список';
$lang['dropdown_options'] = 'Элементы выпадающего списка <em>(применимо только для полей типа "выпадающий список")</em><br/><br/><em>(все элементы в разных строках)</em>';
$lang['edit'] = 'Редактировать';
$lang['edit_attribset'] = 'Редактировать атрибут';
$lang['edit_attribsets'] = 'Редактировать набор атрибутов';
$lang['edit_attribsets_for'] = 'Редактировать набор атрибутов для';
$lang['edit_attributes'] = 'Редактировать атрибуты';
$lang['edit_category'] = 'Редактировать категорию';
$lang['edit_category_fields'] = 'Редактировать поля категории';
$lang['edit_hierarchy_item'] = 'Редактировать элемент иерархии';
$lang['error_attribset_exists'] = 'Атрибут с этим именем уже существует';
$lang['error_duplicate_sku'] = 'Дублируется значение SKU';
$lang['error_fieldvalue_empty'] = 'Необходимо заполнить поле';
$lang['error_fileformat'] = 'Ошибка формата файла';
$lang['error_filenotfound'] = 'Файл не найден';
$lang['error_fileopen'] = 'Не удалось открыть файл %s';
$lang['error_invalidparent'] = 'Invalid Parent (a hierarchy node cannot be it\'s own parent)';
$lang['error_invalid_name'] = 'The custom field value entered is invalid (contains non alphanumeric characters)';
$lang['error_invalid_value'] = 'Указано неверное значение';
$lang['error_missingparam'] = 'Обязательный параметр пропущен или указан неверно';
$lang['error_nameused'] = 'Товар с таким названием уже существует';
$lang['error_nofieldtype'] = 'Пожалуйста укажите тип поля';
$lang['error_noname'] = 'Вы должны указать имя';
$lang['error_onesubscriptionfield'] = 'Only one subscription field is allowed';
$lang['error_permissiondenied'] = 'Доступ запрещен';
$lang['error_product_aliasused'] = 'Указаный алиас уже используется';
$lang['error_product_nameused'] = 'Товар с таким названием уже существует';
$lang['error_product_notfound'] = 'Запрашиваемый товар не найден';
$lang['error_product_skuused'] = 'That SKU value is already in use by another product';
$lang['error_price_adjustment'] = 'Invalid price adjustment value for item %s';
$lang['error_upload_failed'] = 'Upload failed: %s';
$lang['expire_six_months'] = 'After Six Months';
$lang['expire_one_year'] = 'After One Year';
$lang['expire_two_year'] = 'After Two Years';
$lang['extra1'] = 'Дополнительное поле 1';
$lang['extra2'] = 'Дополнительное поле 2';
$lang['field'] = 'Поле';
$lang['fielddef'] = 'Field Definition';
$lang['fielddefs'] = 'Поля';
$lang['file'] = 'Файл';
$lang['filters'] = 'Фильтр';
$lang['firstpage'] = '<<';
$lang['general_settings'] = 'Общие настройки';
$lang['go'] = 'Go';
$lang['hierarchy'] = 'Иерархия';
$lang['hierarchy_position'] = 'Позиция в иерархии';
$lang['hierarchy_settings'] = 'Hierarchy Settings';
$lang['id'] = ' Код';
$lang['imagetext'] = 'Изображение';
$lang['image_handling_settings'] = 'Image Handling Settings';
$lang['import_from_csv'] = 'Импорт продуктов из CSV файла';
$lang['inches'] = 'Inches';
$lang['include_children'] = 'Включать подкатегории?';
$lang['info_alnumonly'] = 'Только латинские буквенно-цифровые символы. Без пробелов, кавычки, или непечатаемых символов';
$lang['info_attribtemplate'] = 'Possible variables are: {$attrib_text},{$attrib_adjust},{$currency_symbol}';
$lang['info_attributes_copied'] = 'Attributes Copied';
$lang['info_autowatermark'] = 'Параметры водных знаков устанавливаються из CGExtensions модуля';
$lang['info_batchsize'] = 'Set the number of lines to process per "batch".  After a batch is complete, the importer will redirect, and resume operations.  If you are experiencing memory errors, or timeout problems due to large amounts of processing, you may need to consult your host provider, or reduce this number';
$lang['info_cart_module_params'] = 'These parameters are given to the selected cart module from the product detail and summary displays';
$lang['info_copy_attribsets'] = 'This action will copy Attribute sets (excluding sku values) from another product.';
$lang['info_createfields'] = 'Create unknown product fields automatically? <em>(They will be created as text fields)</em>';
$lang['info_createcategories'] = 'Automatically create product categories to match those of the CSV file, if it does not already exist';
$lang['info_createhierarchy'] = 'Automatically create product hierarchies to match those of the CSV file if it does not already exist';
$lang['info_decimal_units'] = 'В качестве десятичного разделителя используйте точку (.) например: <strong> 59.90 </ STRONG>';
$lang['info_delimiter'] = 'Specify the character (or characters) that seperate each field';
$lang['info_duplicateproducts'] = 'Specify how the system should handle a product whos name already exists in the CSV file';
$lang['info_fielddefs_tab'] = '<strong>Примечание: </strong> Все поля определяемые здесь доступны для всех товаров.';
$lang['info_fieldproblems'] = 'Возникли проблемы при работе с одним или более пользовательских полей. действие завершено успешно, однако вы должны изучить и исправить эти проблемы.';
$lang['info_handleimages'] = 'Upon import, if an image filename is found in a field column, should it be moved from the source location, watermarked, thumbnailed, and the field type changed to "image"';
$lang['info_hierpage'] = 'Use this page for hierarchy views.  The pageid will not be spefiried on the URL.';
$lang['info_imagepath'] = 'The path (relative to the uploads directory) where images referred to in the import file, can be found';
$lang['info_import_test_passed'] = 'A brief test as been performed on the input file specified, and everything appears to be correct.<br/>This is no indication that there are no errors in the file.';
$lang['info_prettyhierurls'] = 'Include the hierarchy item name on the URL';
$lang['info_price_adjustment'] = 'Допустимые значения +-*#.##';
$lang['info_prodnotfound'] = 'This option determines the behaviour of the website if a product detail view is accessed directly by URL, and that product for whatever reason (disabled, deleted, etc) cannot be accessed.';
$lang['info_publicfield'] = 'Публичные поля доступны для просмотра посетителями';
$lang['label'] = 'Подпись';
$lang['label_skip'] = 'Пропустить';
$lang['label_overwrite'] = 'Перезаписать';
$lang['lastpage'] = '>>';
$lang['last_modified'] = 'Изменен';
$lang['logotext'] = 'Второе изображение';
$lang['maxlength'] = 'Maximum length <em>(applicable only on textbox fields)</em>';
$lang['modifieddate'] = 'Изменен';
$lang['module_description'] = 'A module for managing a catalog of products, their price, images, etc, and for allowing users to build a cart';
$lang['move_down'] = 'Move Down';
$lang['move_up'] = 'Move Up';
$lang['name'] = 'Название';
$lang['needpermission'] = 'You do not have the required permission: %s';
$lang['new_category_name'] = 'Новое название категории';
$lang['nextpage'] = '>';
$lang['no'] = 'Нет';
$lang['nonamegiven'] = 'No name was supplied';
$lang['none'] = '<Нет>';
$lang['of'] = 'Из';
$lang['page'] = 'Страница';
$lang['page_of'] = 'Страница %s из %s';
$lang['page_limit'] = 'Продуктов на странице';
$lang['param_action'] = 'Specify the behaviour of the module.  Possible values are:
<ul>
  <li>hierarchy -- Display a product list by hierarchy</li>
  <li>categorylist - Display a list of product categories</li>
  <li><em>default</em> - Display a summary of products</li>
  <li>details - Display a detail view of a single product</li>
</ul>';
$lang['param_category'] = 'When used in the <em>default</em> summary mode, this parameter, which should match the name of an existing category will be used to display only those products that are in that categoory. (a comma seperated list can be supplied)';
$lang['param_categorylisttemplate'] = 'Useful only with the categorylist action, this parameter indicates the template that should be used for the display.  If no value is specified then the current default template of that type is used.';
$lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist actions, this parameter indicates the template that should be used for the display of the category details.  This uses a category list template..  If no value is specified then the current default template of that type is used.';
$lang['param_detailpage'] = 'This specifies the pageid or alias that should be used to display the detail report.';
$lang['param_detailtemplate'] = 'This parameter specifies the template that should be used for the detail mode display.  If no value is specified, then the current default template of that type is used.';
$lang['param_field'] = 'Used only in the <em>fieldlist</em> this parameter is required to specify the name of a user defined property to create a list from.';
$lang['param_fieldval'] = 'Used only in the <em>default</em> action, this parameter allows specifying a field value to limit results by.  Special values for this field are "::null::" "::notnull::"';
$lang['param_hierarchy'] = 'Useful only in the <em>default</em> action, this parameter specifies that only items in that location of the hierarchy should be displayed.  Wildcard character can be used so that you can specify parent/child relationships as well.  i.e {Products hierarchy=\'trucks*\'} will create a summary report of all trucks, including the children in the hierarchy.  Similarly, {Products hierarchy=\'*trucks\'} will display a summary report of all trucks, and all products beloging to any parent in the hierarchy.';
$lang['param_hierarchytemplate'] = 'This parameter specifies the template that should be used for the hierarchy display. If no value is specified, then the current default template of that type is used.';
$lang['param_inline'] = 'Useful only with the search action, this parameter specifies that the output of the summary view should be displayed inline';
$lang['param_pagelimit'] = 'Useful only with the <em>default</em> action, this parameter specifies how many items should be listed on each page.';
$lang['param_parent'] = 'Useful only in the <em>hierarchy</em> action, this parameter specifies the hierarchy id of the starting location of the report.';
$lang['param_productid'] = 'Useful only with the detail action, this parameter indicates what product to use for the display.';
$lang['param_productlist'] = 'Applicable only to the default (summary) view, this parameter allows specifying a comma separated list of integer product ids to display.  No pagination or sorting is performed on these values, and if specified the other filtering parameters to the summary view are ignored.';
$lang['param_resultpage'] = 'Applicable only to the search, and category list actions, this parameter specifies a page id or alias to use to display the summary results';
$lang['param_searchfield'] = 'Applicable only to the search action, this parameter may contain a comma separated list of field names to include in the search';
$lang['param_searchformtemplate'] = 'Applicable only to the search action, thisparameter allows specifying a non default search form template';
$lang['param_showall'] = 'Applicable only to the categorylist and fieldlist actions, if this parameter is set to a non 0 integer value all categories (even those without products) will be displayed.';
$lang['param_sortorder'] = 'Specify the order of sorted fields in summary view.  Possible values are:
<ul>
  <li><strong>asc</strong> -- Ascending order</li>
  <li>desc -- Descending order</li>
</ul>';
$lang['param_sortby'] = 'Applicable only in summary mode, this parameter determines the sorting of the output products.  Possible values are:
<ul>
  <li><strong>product_name</strong></li>
  <li>id -- The product id</li>
  <li>weight -- The product weight</li>
  <li>price -- The product base price</li>
  <li>status -- Draft or published</li>
  <li>random -- Display in random order on each request</li>
  <li>created -- The creation date for this company record</li>
  <li>modified -- The modified date for this company record</li>
</ul>';
$lang['param_sorttype'] = 'Applicable only to the default summary view, this parameter is used to convert the values to another type for sorting.  valid values are STRING,SIGNED and UNSIGNED.  If not supplied the default STRING type is assumed.';
$lang['param_summarypage'] = 'Applicable only to the action=hierarchy, allows specifying a page id or alias that will be used for any links to summary view';
$lang['param_summarytemplate'] = 'This parameter specifies the template that should be used for the summary mode display.  If no value is specified, then the current default template of that type is used.';
$lang['parent'] = 'Родитель';
$lang['postinstall'] = 'The Products module has been successfully installed';
$lang['postuninstall'] = 'The Products module has been removed along with all associated data';
$lang['preferences'] = 'Настройки';
$lang['preuninstall'] = 'Removing this module will also remove all associated data, are you sure you want to proceed?';
$lang['price'] = 'Цена';
$lang['price_adjustment'] = 'Корректировка цен';
$lang['prevpage'] = '<';
$lang['product'] = 'Товар';
$lang['productname'] = 'Название';
$lang['products'] = 'Товары';
$lang['product_detail_settings'] = 'Product Detail Settings';
$lang['product_editing_settings'] = 'Product Editing Settings';
$lang['product_summary_settings'] = 'Product Summary Settings';
$lang['product_hierarchy'] = 'Иерархия Каталога';
$lang['product_manager'] = 'Управление продуктами';
$lang['progress'] = 'Progress';
$lang['prompt'] = 'Подсказка';
$lang['prompt_add_attribset'] = 'Add/Edit Attribute Set';
$lang['prompt_allowed_filetypes'] = 'Разрешить загружать файлы с расширениями (для пользовательских полей типа "файл")';
$lang['prompt_allowed_imagetypes'] = 'Разрешить загружать изображения с этими расширениями (для пользовательских полей типа "изображение")';
$lang['prompt_attribtemplate'] = 'Template for display of product attribute values in dropdown';
$lang['prompt_autothumbnail'] = 'Автоматически создавать эскизы изображений';
$lang['prompt_autothumbnail_size'] = 'Maximum size (largest dimension) of the thumbnail.';
$lang['prompt_autopreviewimg'] = 'Automatically create preview images of images';
$lang['prompt_autopreviewimg_size'] = 'Maximum size (largest dimension) of the preview image.';
$lang['prompt_autowatermark'] = 'Автоматически ставить водяные знаки на изображениях';
$lang['prompt_applicable'] = 'Enable by default for all new products';
$lang['prompt_batchsize'] = 'Batch Size';
$lang['prompt_cart_module'] = 'Модуль корзины';
$lang['prompt_cart_module_params'] = 'Парметры модуля корзины';
$lang['prompt_createcategories'] = 'Create Categories';
$lang['prompt_createfields'] = 'Create Product Fields?';
$lang['prompt_createhierarchy'] = 'Create Product Hierarchy';
$lang['prompt_csvfile'] = 'Загрузить CVS файл';
$lang['prompt_currencycode'] = 'Код валюты';
$lang['prompt_currencysymbol'] = 'Символ валюты';
$lang['prompt_default_status'] = 'По умолчанию все новые продукты имеют статус';
$lang['prompt_default_taxable'] = 'По умолчанию все новые продукты облагаются налогом';
$lang['prompt_deleteproductfiles'] = 'Удалять все файлы, связанные с продуктом, когда продукт будет удален?';
$lang['prompt_delimiter'] = 'Field Delimiter';
$lang['prompt_detailpage'] = 'Страница описания товара по умолчанию';
$lang['prompt_detailsfor'] = 'Details for %s';
$lang['prompt_duplicateproducts'] = 'How to handle duplicate products?';
$lang['prompt_false'] = 'False';
$lang['prompt_handleimages'] = 'Handle images?';
$lang['prompt_imagepath'] = 'Image Path';
$lang['prompt_lengthunits'] = 'Length Units';
$lang['prompt_notfound_behavior'] = 'What action should be taken when a product cannot be displayed?';
$lang['prompt_notfound_404'] = 'Generate a 404 error';
$lang['prompt_notfound_301'] = 'Generate a 301 redirect';
$lang['prompt_notfound_errormsg'] = 'Display an error message';
$lang['prompt_notfound_msg'] = 'Error message for when a product cannot be found';
$lang['prompt_notfound_page'] = 'Page to do permanent redirect to?';
$lang['prompt_hierpage'] = 'Default Page for Hierarchy View';
$lang['prompt_prettyhierurls'] = 'Use Pretty URLS to Hierarchy Views';
$lang['prompt_prod_detailpage'] = 'Default Page for Product Detail Views';
$lang['prompt_products_matching'] = 'Products matching %s';
$lang['prompt_summarypagelimit'] = 'Default page limit in summary mode';
$lang['prompt_summarysortorder'] = 'Порядок сортировки по умолчанию в суммарном режиме';
$lang['prompt_summarysorting'] = 'Поля сортировки по умолчанию в суммарном режиме';
$lang['prompt_template'] = 'Template Source';
$lang['prompt_true'] = 'True';
$lang['prompt_urlprefix'] = 'Prefix to use on all URLS targeted to this this module';
$lang['prompt_use_detailpage_for_search'] = 'Use this page for search results too <em>(overrides the searchresults page parameter in the search module)</em>';
$lang['prompt_usehierpathurls'] = 'Use Hierarchy Path in Product Detail URLS';
$lang['prompt_weightunits'] = 'Единица веса';
$lang['public'] = 'Является ли это поле публичным?';
$lang['published'] = 'Опубликован';
$lang['random'] = 'Random';
$lang['resettofactory'] = 'Reset to Factory Values';
$lang['return'] = 'Назад';
$lang['return_to_top'] = 'Return to the top of the view';
$lang['root'] = 'Каталог';
$lang['search_description'] = 'Search Property Description';
$lang['search_expr'] = 'Should the query match all, or any of the tests below?';
$lang['search_name'] = 'Search Property Name';
$lang['search_price'] = 'Price Range';
$lang['searchtemplate_addedit'] = 'Add/Edit Search Form Template';
$lang['searchtemplates'] = 'Search Templates';
$lang['select_one'] = 'Select One';
$lang['sku'] = 'SKU';
$lang['sort_by'] = 'Сортировать по';
$lang['sort_order'] = 'Порядок сортировки';
$lang['source'] = 'Source';
$lang['status'] = 'Статус';
$lang['submit'] = 'Отправить';
$lang['subscription'] = 'Subscription';
$lang['subscr_expiry'] = 'Expiry';
$lang['subscr_expiry2'] = 'Expires';
$lang['subscr_monthly'] = 'Monthly';
$lang['subscr_delperiod'] = 'Delivery Frequency';
$lang['subscr_delperiod2'] = 'Delievered';
$lang['subscr_payperiod'] = 'Payment Frequency';
$lang['subscr_payperiod2'] = 'Paid';
$lang['subscr_quarterly'] = 'Quarterly';
$lang['subscr_semianually'] = 'Semi Anually';
$lang['subscr_yearly'] = 'Yearly';
$lang['summarytemplates'] = 'Суммарный шаблон';
$lang['summarytemplate_addedit'] = 'Добавить/Редактировать суммарный шаблон';
$lang['taxable'] = 'Облагаемый налогом';
$lang['test'] = 'Проверка';
$lang['textarea'] = 'Текстовая область';
$lang['textbox'] = 'Текстовая строка';
$lang['title_byhierarchy_dflttemplate'] = 'Шаблон иерархии по умолчанию';
$lang['title_categorylist_dflttemplate'] = 'Шаблон списка категорий по умолчанию';
$lang['title_detail_dflttemplate'] = 'Шаблон карточки товара по умолчанию';
$lang['title_search_dflttemplate'] = 'Default New Search Template';
$lang['title_summary_dflttemplate'] = 'Суммарный шаблон по умолчанию';
$lang['type'] = 'Тип';
$lang['up'] = 'Move Up';
$lang['update'] = 'Обновить';
$lang['upload'] = 'Выберите файл для загрузки';
$lang['url_alias'] = 'URL Alias';
$lang['valid'] = 'Valid';
$lang['value'] = 'Значение';
$lang['values'] = 'Значения';
$lang['view'] = 'View';
$lang['viewable_fields'] = 'Select custom fields to view in the table';
$lang['watermark_location'] = 'Расположение водяных знаков(подписи на изображение)';
$lang['weight'] = 'Вес';
$lang['yes'] = 'Да';
$lang['utma'] = '156861353.1586252174.1302554112.1302554112.1302554112.1';
$lang['utmb'] = '156861353.4.9.1302554623453';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1302554112.1.1.utmcsr=yandex|utmccn=(organic)|utmcmd=organic|utmctr=cms made simple';
$lang['qca'] = 'P0-54757025-1302554112098';
?>
